From df8b908794563cb3aef9ef9ed17228779c00f4d1 Mon Sep 17 00:00:00 2001
From: Bharath Rupireddy <bharath.rupireddyforpostgres@gmail.com>
Date: Fri, 9 Sep 2022 03:40:37 +0000
Subject: [PATCH v1] Use float8 datatype for percentiles in pg_walinspect stat
 functions

pg_walinspect uses datatype double (double precision floating point
number) for WAL stats percentile calculations and expose them via
float4 (single precision floating point number), which an unnecessary
loss of precision and confusing. Even though, it's harmless that way,
let's use float8 (double precision floating-point number) to be in
sync with what pg_walinspect does internally and what it exposes to
the users. This seems to be the pattern used elsewhere in the code.

Reported-by: Peter Eisentraut
Author: Bharath Rupireddy
Reviewed-by: Peter Eisentraut
Discussion: https://www.postgresql.org/message-id/36ee692b-232f-0484-ce94-dc39d82021ad%40enterprisedb.com
---
 contrib/pg_walinspect/pg_walinspect--1.0.sql | 16 ++++++++--------
 contrib/pg_walinspect/pg_walinspect.c        |  8 ++++----
 doc/src/sgml/pgwalinspect.sgml               | 16 ++++++++--------
 3 files changed, 20 insertions(+), 20 deletions(-)

diff --git a/contrib/pg_walinspect/pg_walinspect--1.0.sql b/contrib/pg_walinspect/pg_walinspect--1.0.sql
index 4243516d8a..08b3dd5556 100644
--- a/contrib/pg_walinspect/pg_walinspect--1.0.sql
+++ b/contrib/pg_walinspect/pg_walinspect--1.0.sql
@@ -80,13 +80,13 @@ CREATE FUNCTION pg_get_wal_stats(IN start_lsn pg_lsn,
     IN  per_record boolean DEFAULT false,
     OUT "resource_manager/record_type" text,
     OUT count int8,
-    OUT count_percentage float4,
+    OUT count_percentage float8,
     OUT record_size int8,
-    OUT record_size_percentage float4,
+    OUT record_size_percentage float8,
     OUT fpi_size int8,
-    OUT fpi_size_percentage float4,
+    OUT fpi_size_percentage float8,
     OUT combined_size int8,
-    OUT combined_size_percentage float4
+    OUT combined_size_percentage float8
 )
 RETURNS SETOF record
 AS 'MODULE_PATHNAME', 'pg_get_wal_stats'
@@ -102,13 +102,13 @@ CREATE FUNCTION pg_get_wal_stats_till_end_of_wal(IN start_lsn pg_lsn,
     IN  per_record boolean DEFAULT false,
     OUT "resource_manager/record_type" text,
     OUT count int8,
-    OUT count_percentage float4,
+    OUT count_percentage float8,
     OUT record_size int8,
-    OUT record_size_percentage float4,
+    OUT record_size_percentage float8,
     OUT fpi_size int8,
-    OUT fpi_size_percentage float4,
+    OUT fpi_size_percentage float8,
     OUT combined_size int8,
-    OUT combined_size_percentage float4
+    OUT combined_size_percentage float8
 )
 RETURNS SETOF record
 AS 'MODULE_PATHNAME', 'pg_get_wal_stats_till_end_of_wal'
diff --git a/contrib/pg_walinspect/pg_walinspect.c b/contrib/pg_walinspect/pg_walinspect.c
index 2f51a8dec4..38fb4106da 100644
--- a/contrib/pg_walinspect/pg_walinspect.c
+++ b/contrib/pg_walinspect/pg_walinspect.c
@@ -430,13 +430,13 @@ FillXLogStatsRow(const char *name,
 
 	values[i++] = CStringGetTextDatum(name);
 	values[i++] = Int64GetDatum(n);
-	values[i++] = Float4GetDatum(n_pct);
+	values[i++] = Float8GetDatum(n_pct);
 	values[i++] = Int64GetDatum(rec_len);
-	values[i++] = Float4GetDatum(rec_len_pct);
+	values[i++] = Float8GetDatum(rec_len_pct);
 	values[i++] = Int64GetDatum(fpi_len);
-	values[i++] = Float4GetDatum(fpi_len_pct);
+	values[i++] = Float8GetDatum(fpi_len_pct);
 	values[i++] = Int64GetDatum(tot_len);
-	values[i++] = Float4GetDatum(tot_len_pct);
+	values[i++] = Float8GetDatum(tot_len_pct);
 
 	Assert(i == ncols);
 }
diff --git a/doc/src/sgml/pgwalinspect.sgml b/doc/src/sgml/pgwalinspect.sgml
index de63a70965..1a1bee7d6a 100644
--- a/doc/src/sgml/pgwalinspect.sgml
+++ b/doc/src/sgml/pgwalinspect.sgml
@@ -164,13 +164,13 @@ postgres=# select start_lsn, end_lsn, prev_lsn, xid, resource_manager, record_ty
                        per_record boolean DEFAULT false,
                        "resource_manager/record_type" OUT text,
                        count OUT int8,
-                       count_percentage OUT float4,
+                       count_percentage OUT float8,
                        record_length OUT int8,
-                       record_length_percentage OUT float4,
+                       record_length_percentage OUT float8,
                        fpi_length OUT int8,
-                       fpi_length_percentage OUT float4,
+                       fpi_length_percentage OUT float8,
                        combined_size OUT int8,
-                       combined_size_percentage OUT float4)
+                       combined_size_percentage OUT float8)
       returns setof record
      </function>
     </term>
@@ -241,13 +241,13 @@ postgres=# select * from pg_get_wal_stats('0/14AFC30', '0/15011D7', true) where
                                        per_record boolean DEFAULT false,
                                        "resource_manager/record_type" OUT text,
                                        count OUT int8,
-                                       count_percentage OUT float4,
+                                       count_percentage OUT float8,
                                        record_length OUT int8,
-                                       record_length_percentage OUT float4,
+                                       record_length_percentage OUT float8,
                                        fpi_length OUT int8,
-                                       fpi_length_percentage OUT float4,
+                                       fpi_length_percentage OUT float8,
                                        combined_size OUT int8,
-                                       combined_size_percentage OUT float4)
+                                       combined_size_percentage OUT float8)
       returns setof record
      </function>
     </term>
-- 
2.34.1

